@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_kms._jsii
 import aws_cdk.aws_lambda._jsii
@@ -18,9 +18,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-solutions-constructs/aws-sqs-lambda",
-    "1.60.0",
+    "1.62.0",
     __name__[0:-6],
-    "aws-sqs-lambda@1.60.0.jsii.tgz",
+    "aws-sqs-lambda@1.62.0.jsii.tgz",
 )
 
 __all__ = [
